@@ -5,6 +5,7 @@
 # License-Filename: LICENSE
 
 
+import os
 import sys
 from pathlib import Path
 from subprocess import run
@@ -36,13 +37,6 @@ def execute_todo(exe_path, task_path):
         dir = Path("/etc/todo.txt-base/{}hooks/".format(phase))
         run_hooks(str(dir), task_path)
 
-    # TODO - temp
-    # this is a temp kluge to bridge from v1.1 to v2.0
-    if phase == "ls":
-        print("running kluge")
-        cp = run("cd /tmp; /usr/bin/topydo ls", shell=True, capture_output=True, encoding="utf-8")
-        print(cp.stdout)
-
 
 @tdtwrapper
 @prehook
@@ -56,3 +50,11 @@ def backup_todo(exe_path, task_path):
     backup_path = Path(task_path).parent / "backup"
     sys.argv = ["backuptodo", "-f", task_path, "-b", str(backup_path)] + sys.argv[1:]
     tdtbackup.main()
+
+
+@tdtwrapper
+def cd_todo(exe_path, task_path):
+    task_dir_path = Path(task_path).parent
+    shell_path = os.getenv("SHELL")
+    os.chdir(str(task_dir_path))
+    run(shell_path)
